pub type EmptyProcState = Box<EmptyState>;Expand description
Empty proc state which is an heap allocated empty struct.
Aliased Type
pub struct EmptyProcState(/* private fields */);pub type EmptyProcState = Box<EmptyState>;Empty proc state which is an heap allocated empty struct.
pub struct EmptyProcState(/* private fields */);